@@ -21,13 +21,14 @@
 #include <stdio.h>
 #include <string.h>
 
+int
 main(argc,argv)
 int argc;
 char **argv;
 {
   char c;
   printf("(:any :size %d :bytes #( ", strlen(argv[1]));
-  while(c = *argv[1]++) printf("%d ", c);
+  while( (c = (*argv[1]++)) ) printf("%d ", c);
   printf(") )\n");
   exit(0);
 }
